@@ -36,7 +36,7 @@ def snake_case(camel_case: str) -> str:
 
 class MemInfo:
     _METRIC_REGEXP = re.compile(
-        r"^(?P<name>[^\(]+(\((?P<label>\S+)\))?):\s*"
+        r"^(?P<name>[^[\(]+)(\((?P<label>\S+)\))?:\s*"
         r"(?P<value>\d+)(\s?(?P<suffix>\S+))?$",
     )
 
@@ -46,7 +46,9 @@ class MemInfo:
         for line in fp:
             match = self._METRIC_REGEXP.match(line)
             if match is None:
+                log.debug("Skip line %r", line)
                 continue
+
             parsed = match.groupdict()
             name = parsed.get("name")
             value = parsed.get("value")
